@@ -2,6 +2,7 @@
 
 ExerciseDialog::ExerciseDialog(QWidget *parent)
 {
+    closing = false;
     setAttribute(Qt::WA_Maemo5StackedWindow);
     setAttribute(Qt::WA_Maemo5PortraitOrientation);
 
@@ -37,13 +38,15 @@ void ExerciseDialog::load(QList <QString> exercises)
 
 void ExerciseDialog::start()
 {
+    closing = true;
     QString name = lstExercises->currentIndex().data().toString();
     emit exerciseName(name);
 
-    emit close();
+    emit destroyDialog();
 }
 
 void ExerciseDialog::closeEvent(QCloseEvent *event)
 {
-    return event->ignore();
+    if(closing == false)
+        return event->ignore();
 }
